API docs for “spamfighter.core.commands”

# Package s.c.commands

Part of spamfighter.core View Source

Базовые классы для обработки команд API сервера.

Module | apiglue | "Клей", позволяющий приклеить нашу систему команд к Twisted-варианту XML-RPC & JSON-RPC.
Module | command | Базовый класс команды API.
Module | dispatcher | Диспетчеризация команд по имени.
Module | errors | Базовые классы обработки ошибок при выполнении команд.
Module | partner | Команды с поддержкой выбора партнера и домена.
Module | serialize | Поддержка сериализации/десериализации для типов данных, передаваемых в командах.
Package | test | Тесты на `spamfighter.core.commands`.